@@ -18,7 +18,7 @@ use parent qw(Mojo::WebSocketProxy::Backend);
 
 no indirect;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 __PACKAGE__->register_type('consumer_groups');
 
@@ -260,21 +260,22 @@ sub _prepare_request_data {
     my ($self, $c, $req_storage, $req_timeout) = @_;
 
     $req_storage->{call_params} ||= {};
-
+    my $req_log_context;
     my $method   = $req_storage->{method};
     my $msg_type = $req_storage->{msg_type} ||= $req_storage->{method};
 
-    my $params = $self->make_call_params($c, $req_storage);
-    $params->{correlation_id} = $c->stash('correlation_id');
+    my $params       = $self->make_call_params($c, $req_storage);
     my $stash_params = $req_storage->{stash_params};
+    $req_log_context = $req_storage->{logger}->get_context() if $req_storage->{logger};
 
     my $request_data = [
         rpc      => $method,
         who      => $self->whoami,
         deadline => time + $req_timeout,
 
-        $params       ? (args  => encode_json_utf8($params))       : (),
-        $stash_params ? (stash => encode_json_utf8($stash_params)) : (),
+        $params          ? (args            => encode_json_utf8($params))          : (),
+        $stash_params    ? (stash           => encode_json_utf8($stash_params))    : (),
+        $req_log_context ? (req_log_context => encode_json_utf8($req_log_context)) : (),
     ];
 
     return $msg_type, $request_data;
@@ -294,7 +295,7 @@ Mojo::WebSocketProxy::Backend::ConsumerGroups - Class for communication with bac
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
